@@ -432,11 +432,13 @@ class AbstractFieldData(CollectionData, ABC):
                 flip_inds = np.where(coords < center)[0]
 
                 # Get the symmetric coordinates on the right
-                coords[flip_inds] = 2 * center - coords[flip_inds]
+                coords_interp = np.copy(coords)
+                coords_interp[flip_inds] = 2 * center - coords[flip_inds]
 
                 # Interpolate. There generally shouldn't be values out of bounds except potentially
                 # when handling modes, in which case we set such values to zero.
-                new_data = new_data.interp({dim_name: coords}, kwargs={"fill_value": 0.0})
+                new_data = new_data.interp({dim_name: coords_interp}, kwargs={"fill_value": 0.0})
+                new_data = new_data.assign_coords({dim_name: coords})
 
                 # Apply the correct +/-1 for the field component
                 new_data[{dim_name: flip_inds}] *= sym * component_sym_dict[field][dim]
@@ -515,7 +517,7 @@ class ScalarFieldData(AbstractScalarFieldData, FreqData):
 
     def normalize(self, source_freq_amps: Array[complex]) -> None:
         """normalize the values by the amplitude of the source."""
-        self.values /= 1j * source_freq_amps  # pylint: disable=no-member
+        self.values /= 1 * source_freq_amps  # pylint: disable=no-member
 
 
 class ScalarFieldTimeData(AbstractScalarFieldData, TimeData):
@@ -687,7 +689,7 @@ class ModeAmpsData(AbstractModeData):
 
     def normalize(self, source_freq_amps: Array[complex]) -> None:
         """normalize the values by the amplitude of the source."""
-        self.values /= 1j * source_freq_amps  # pylint: disable=no-member
+        self.values /= 1 * source_freq_amps  # pylint: disable=no-member
 
 
 class ModeIndexData(AbstractModeData):
@@ -799,7 +801,7 @@ class SimulationData(Tidy3dBaseModel):
     simulation : :class:`Simulation`
         Original :class:`Simulation` that was run to create data.
     monitor_data : Dict[str, :class:`Tidy3dData`]
-        Mapping of monitor name to :class:`Tidy3dData` intance.
+        Mapping of monitor name to :class:`Tidy3dData` instance.
     log_string : str = None
         A string containing the log information from the simulation run.
     diverged : bool = False
