@@ -11,14 +11,12 @@ from shapely.geometry import Point, Polygon, box
 from descartes import PolygonPatch
 
 from .base import Tidy3dBaseModel
-from .types import Bound, Size, Coordinate, Axis, Coordinate2D, ArrayLike
+from .types import Bound, Size, Coordinate, Axis, Coordinate2D, tidynumpy
 from .types import Vertices, Ax, Shapely
 from .viz import add_ax_if_none, equal_aspect
+from .viz import PLOT_BUFFER, ARROW_LENGTH_FACTOR, ARROW_WIDTH_FACTOR
 from ..log import Tidy3dKeyError, SetupError, ValidationError
-from ..constants import MICROMETER
-
-# add this around extents of plots
-PLOT_BUFFER = 0.3
+from ..constants import MICROMETER, LARGE_NUMBER
 
 
 class Geometry(Tidy3dBaseModel, ABC):
@@ -281,12 +279,21 @@ class Geometry(Tidy3dBaseModel, ABC):
         """
         xlabel, ylabel = self._get_plot_labels(axis=axis)
         (xmin, xmax), (ymin, ymax) = self._get_plot_limits(axis=axis, buffer=buffer)
+
+        # note: axes limits dont like inf values, so we need to evaluate them first if present
+        xmin, xmax, ymin, ymax = self._evaluate_infs(xmin, xmax, ymin, ymax)
+
         ax.set_xlim(xmin, xmax)
         ax.set_ylim(ymin, ymax)
         ax.set_xlabel(xlabel)
         ax.set_ylabel(ylabel)
         return ax
 
+    @staticmethod
+    def _evaluate_infs(*values):
+        """Processes values and evaluates any infs into large (signed) numbers."""
+        return map(lambda v: v if not np.isinf(v) else np.sign(v) * LARGE_NUMBER, values)
+
     @staticmethod
     def pop_axis(coord: Tuple[Any, Any, Any], axis: int) -> Tuple[Any, Tuple[Any, Any]]:
         """Separates coordinate at ``axis`` index from coordinates on the plane tangent to ``axis``.
@@ -617,6 +624,87 @@ class Box(Geometry):
         """
         return Box(center=self.center, size=self.size)
 
+    def _plot_arrow(  # pylint:disable=too-many-arguments, too-many-locals
+        self,
+        direction: Tuple[float, float, float],
+        x: float = None,
+        y: float = None,
+        z: float = None,
+        color: str = None,
+        alpha: float = None,
+        length_factor: float = ARROW_LENGTH_FACTOR,
+        width_factor: float = ARROW_WIDTH_FACTOR,
+        both_dirs: bool = False,
+        ax: Ax = None,
+    ) -> Ax:
+        """Adds an arrow to the axis if with options if certain conditions met.
+
+        Parameters
+        ----------
+        direction: Tuple[float, float, float]
+            Normalized vector describing the arrow direction.
+        x : float = None
+            Position of plotting plane in x direction.
+        y : float = None
+            Position of plotting plane in y direction.
+        z : float = None
+            Position of plotting plane in z direction.
+        color : str = None
+            Color of the arrow.
+        alpha : float = None
+            Opacity of the arrow (0, 1)
+        length_factor : float = None
+            How long the (3D, unprojected) arrow is compared to the min(height, width) of the axes.
+        width_factor : float = None
+            How wide the (3D, unprojected) arrow is compared to the min(height, width) of the axes.
+        both_dirs : bool = False
+            If True, plots an arrow ponting in direction and one in -direction.
+
+        Returns
+        -------
+        matplotlib.axes._subplots.Axes
+            The matplotlib axes with the arrow added.
+        """
+
+        plot_axis, _ = self.parse_xyz_kwargs(x=x, y=y, z=z)
+        arrow_axis = [component == 0 for component in direction]
+        arrow_length = self._arrow_length(ax, length_factor)
+
+        # only add arrow if the plotting plane is perpendicular to the source
+        if arrow_axis.count(0.0) > 1 or arrow_axis.index(0.0) != plot_axis:
+            _, (x0, y0) = self.pop_axis(self.center, axis=plot_axis)
+            _, (dx, dy) = self.pop_axis(direction, axis=plot_axis)
+
+            def add_arrow(sign=1.0):
+                """Add an arrow to the axes and include a sign to direction."""
+                ax.arrow(
+                    x=x0,
+                    y=y0,
+                    dx=sign * arrow_length * dx,
+                    dy=sign * arrow_length * dy,
+                    width=width_factor * arrow_length,
+                    color=color,
+                    alpha=alpha,
+                )
+
+            add_arrow(sign=1.0)
+            if both_dirs:
+                add_arrow(sign=-1.0)
+
+        return ax
+
+    def _arrow_length(self, ax: Ax, length_factor: float = ARROW_LENGTH_FACTOR) -> float:
+        """Length of arrow is the minimum size of the axes times the length factor."""
+
+        # get the sizes of the matplotlib axes
+        xmin, xmax = ax.get_xlim()
+        ymin, ymax = ax.get_ylim()
+        ax_width = xmax - xmin
+        ax_height = ymax - ymin
+
+        # apply length factor to the minimum size to get arrow width
+        return length_factor * min(ax_width, ax_height)
+
 
 class Sphere(Circular):
     """Spherical geometry.
@@ -805,7 +893,7 @@ class PolySlab(Planar):
         units=MICROMETER,
     )
 
-    vertices: Union[Vertices, ArrayLike] = pydantic.Field(
+    vertices: Union[Vertices, tidynumpy] = pydantic.Field(
         ...,
         title="Vertices",
         description="List of (d1, d2) defining the 2 dimensional positions of the polygon "
